# -*- coding: utf-8 -*-
# Copyright (C) 2008 Lincoln de Sousa <lincoln@minaslivre.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
from django.db import models
from django.contrib.localflavor.br.br_states import STATE_CHOICES
from django.contrib.auth.models import User
from django.contrib.sites.models import Site

class Evento(models.Model):
    nome = models.CharField(max_length=100)
    data_inicio = models.DateField(u'Data de início')
    data_final = models.DateField()

    local = models.CharField(max_length=100)
    nome_contato = models.CharField(u'Nome do contato', max_length=100)
    telefone = models.CharField(max_length=100)
    endereco = models.TextField()
    cidade = models.CharField(max_length=100)
    estado = models.CharField(max_length=2, choices=STATE_CHOICES)
    info_adicional = models.TextField(blank=True)

    site = models.ForeignKey(Site)

    def __str__(self):
        return self.nome

class Palestrante(models.Model):
    nome = models.CharField(max_length=100)
    email = models.CharField(max_length=100)

    telefone = models.CharField(max_length=100, blank=True)
    celular = models.CharField(max_length=100, blank=True)

    instituicao = models.CharField(u'Instituição', max_length=250, blank=True)

    endereco = models.TextField()
    cep = models.CharField(max_length=8)
    cidade = models.CharField(max_length=100)
    estado = models.CharField(max_length=2, choices=STATE_CHOICES)

    minicurriculo = models.TextField(u'Mini currículo')
    curriculo = models.TextField(u'Currículo')

    usuario = models.ForeignKey(User, help_text=u'Este campo associa o '
                                'palestrante a uma conta no sistema para '
                                'que ele possa enviar trabalhos e alterar '
                                'dados pessoais.')
    class Meta:
        ordering = ['nome']

    def __str__(self):
        return self.nome

class TipoTrabalho(models.Model):
    nome = models.CharField(max_length=100)
    evento = models.ForeignKey(Evento)

    class Meta:
        verbose_name = u'Tipo de trabalho'
        verbose_name_plural = u'Tipos de trabalho'

    def __str__(self):
        return self.nome

class Trilha(models.Model):
    nome = models.CharField(max_length=100)
    evento = models.ForeignKey(Evento)

    def __str__(self):
        return self.nome

class DuracaoTrabalho(models.Model):
    duracao = models.CharField(u'Duração', max_length=100)
    tipo = models.ForeignKey(TipoTrabalho)

    class Meta:
        verbose_name = u'Duração do Trabalho'
        verbose_name_plural = u'Durações do Trabalho'

    def __str__(self):
        return self.duracao

class Trabalho(models.Model):
    titulo = models.CharField(max_length=100)
    evento = models.ForeignKey(Evento)
    tipo = models.ForeignKey(TipoTrabalho)
    trilha = models.ForeignKey(Trilha)
    palestrante = models.ForeignKey(Palestrante)
    descricao_curta = models.TextField(u'Descrição curta')
    descricao_longa = models.TextField(u'Descrição longa')
    recursos = models.TextField(blank=True)
    duracao = models.ForeignKey(DuracaoTrabalho)
    pub_date = models.DateTimeField(u'Data de criação', auto_now_add=True)
    outros_palestrantes = \
        models.ManyToManyField(Palestrante,
                               related_name='outros_palestrantes',
                               blank=True,
                               null=True)

    def __str__(self):
        return self.titulo

class Improve(models.Model):
    trabalho = models.ForeignKey(Trabalho)
    usuario = models.ForeignKey(User, help_text=u'Este campo associa o '
                            'palestrante a uma conta no sistema para '
                            'que ele possa enviar trabalhos e alterar '
                            'dados pessoais.')
    comentario = models.TextField(u'Comentário')
    pub_date = models.DateTimeField(u'Data do Comentário', auto_now_add=True)
